close all
clear all
clc
%% Description
% Created by Magnus Aa Dalen, Spring 2016.
% This script creates a frequency analysis for a suspension bridge. A full analysis is set up, 
% and the script exports an Abaqus input-file. To run the analysis the computer must have access to a valid Abaqus license.
% The author uses Abaqus 6.13-1, but the model is appliccable in other similar versions.
% 
% The script saves the input file in a new folder with the same name as the JobName parameter.
% To run the input file in Abaqus:
%  -    Option 1 (recomended): Shift+right click on the new folder. Choose "open command window here".
%       Paste the code that appears in the Matlab Command Window after running master_script.
%       Press enter to start the analysis. Abaqus will autimatically save all results in the same folder.
%  -    Option 2: Uncomment the bottom three lines in this script. This
%       starts the Abaqus analysis, and opens the Abaqus .odb result file when
%       done. It is the authors experience that it takes more time than option 1.
%%
JobName = 'Suspension_Bridge_Setup3_StiffCB';         %collects all results in a new folder named 'JobName'
L=2050;                                         %Total span-length
L_side= 330;                                    %Side span length
d= 25.5; %11.5 17.5 25.5                        %distance from main girder to side girders (center-center)
D=30;                                           %Distance between cables mid span
D_pylon=D;                                      %Distance between cables over pylons
subheight=40;                                   %Length of pylon legs under the girder
e_vert=0;                                       %vertical distance from side to main girders 

hangers= 137;                                   %must be odd number
number_of_girders = 3;                          %must be either 1 ,2 or 3

girder_sag= 50;                                 %positive curvature of girder before gravity
h=55;                                           %vertical distance from cable to girder before gravity
sag=L/10-40+h;
% sag=110+h;                                    %Sag of cable before gravity loads are applied. 
                                                %The constant must be adjusted to obtain the sag you want after gravity.
%%
% Properties main girder
Ap= [0.5391,0.491949,0,14.01531,.15,0,0]; %A. Iy, Izy, Iz, It,0 , Iw                    SETUP 1-3
% Ap= [0.5813,0.972,0,16.448,2.460,0,4.298]; %A. Iy, Izy, Iz, It,0 ,% Iw                HARDANGER
Ap_1= [210e9, 80.8e9 ]; %E,G
% Ap_2= [8080,0,0,0,217020,12515]; %m , 0,0 ,0, I_mx, I_yy,                             HARDANGER
Ap_2= [3300,0,0,0,0,0]; %m , 0,0 ,0, I_mx, I_yy,                                        SETUP 1-3
% Ap_2= [1400,0,0,0,0,0]; %m , 0,0 ,0, I_mx, I_yy,                                      Setup 3 new config

% Properties side girders
% Bp= [1, 1e-4, 0, 1e-4 ,1e-4,0,1e-4]; %A. Iy, Izy, Iz, It,0 , Iw                       HARDANGER
Bp= [1.225,0.00303,0,0.136336,0.15e-3,0,0];%                                            SETUP 1-3
Bp_1= [210e9,80.8e9]; %E,G
% Bp_2= [8080,0,0,0,217020,12515]; %m , 0,0 ,0, I_mx, I_yy                              HARDANGER
Bp_2= [3050,0,0,0,0,0]; %m , 0,0 ,0, I_mx, I_yy,                                        SETUP 1-3
% Bp_2= [4000,0,0,0,0,0]; %m , 0,0 ,0, I_mx, I_yy,                                      Setup 3 new config

% Properties cables
% Cp= [0.22132, 6E-5, 0, 6E-5, 1.2E-04 ]; %A. Iy, Izy, Iz, It,0 , Iw                    HARDANGER
% Cp_1= [200e9,76.9e9]; %E,G                                                            HARDANGER
Cp= [0.204338, 6e-5, 0, 6e-5, 1.2e-04]; %A. Iy, Izy, Iz, It,0 , Iw                      SETUP 1-3
Cp_1= [205e9,80.8e9]; %E,G                                                              SETUP 1-3

% Properties cross beams
% Dp= [1,1000,0,1000,1000,0,0]; %A. Iy, Izy, Iz, It,0 , Iw                              HARDANGER
Dp= [0.073286,0.034401,0,0.008386,0.02153,0.15e-4,0,0]; %A. Iy,Izy, Iz, It,0 ,Iw        SETUP 1-3
% Dp= [1,1000,0,1000,1000,0,0]; %A. Iy, Izy, Iz, It,0 , Iw                              Stiff crossbeams
Dp_1= [210e9,80.8e9]; %E,G
Dp_2= [575.2,0,0,0,0,0]; %m , 0,0 ,0, I_mx, I_yy,                                       SETUP 1-3
% Dp_2= [1,0,0,0,0,0]; %m , 0,0 ,0, I_mx, I_yy,                                         HARDANGER

% Properties hangers
Ep= [0.01, 0.9e-8, 0, 0.9e-8 ,1.86e-8 ]; %A. Iy, Izy, Iz, It,0 , Iw                     SETUP 1-3
% Ep= [0.0032, 0.9E-8, 0, 0.9E-8 ,1.86E-8  ]; %A. Iy, Izy, Iz, It,0 , Iw                HARDANGER
Ep_1= [160e9, 61.5e9 ]; %E,G



% Properties pylons							
Fp= [17.181	,	172.655	,	0.010	,	124.66	,	224.8967383]; %A. Iy, Izy, Iz, It,0 , Iw
Fp_1= [4.000e+10	,	1.200e+10	,	1.000e-05	]; %E,G
Fp_2= [ 1.231e+11	,	1.007e+11]; %transverse beam stiffness
% Properties pylon stiffeners
Gp= [15.217	,	90.329	,	0.010	,	116.78	,	160.7965276 ]; %A. Iy, Izy, Iz, It,0 , Iw
Gp_1= [4.000e+10	,	1.200e+10	,	1.000e-05]; %E,G
Gp_2= [ 9.229e+10	,	1.080e+11 ]; %transverse beam stiffness
%%
hangers = hangers-1;
%%
[find1,find2,side_cable_a,side_cable_b,side_cable_c,side_cable_d,cable_geo_8000_test, cable_geo_6000_test, cross_beam_geo_2000, cross_beam_geo_4000, crossbeam_pylonbed_1, crossbeam_pylonbed_end, crossbeam_pylontop_1, crossbeam_pylontop_end,crossbeam_pylonmid_1,crossbeam_pylonmid_end, crossbeams_pylon, Girder_geo_2000_test, Girder_geo_4000_test, Girder_geo_main_test, K2, K3, main_nodes_geo, pylon_geo, pylon_geo_6000_1, pylon_geo_6000_end, pylon_geo_8000_1, pylon_geo_8000_end,side_cables_geo_test] = geometry(d,D,D_pylon,e_vert,girder_sag,h,hangers,L,L_side,sag,subheight);

[cable_el_8000,cable_el_6000,Girder_el_main_test,cross_beam_el_2000,cross_beam_el_4000,Girder_el_2000_test,Girder_el_4000_test,hanger_2000_el,hanger_4000_el,pylon_el,crossbeam_pylonbed_1_el,crossbeam_pylonbed_end_el,crossbeam_pylontop_1_el,crossbeam_pylontop_end_el,crossbeam_pylonmid_1,crossbeam_pylonmid_end] = elements(find1,find2,d,D,Girder_geo_main_test,Girder_geo_2000_test,cross_beam_geo_2000,K2,main_nodes_geo,Girder_geo_4000_test,cross_beam_geo_4000,K3,cable_geo_8000_test,side_cable_a,side_cable_c,side_cable_b,cable_geo_6000_test,side_cable_d,pylon_geo_6000_1,pylon_geo_6000_end,pylon_geo_8000_1,pylon_geo_8000_end,crossbeam_pylonbed_1,crossbeam_pylonbed_end,crossbeam_pylontop_1,crossbeam_pylontop_end,crossbeam_pylonmid_1,crossbeam_pylonmid_end);

writefile(number_of_girders,Cp,Cp_1,Dp,Dp_1,Dp_2,Ep,Ep_1,Fp,Fp_1,Fp_2,Gp,Gp_1,Gp_2,Bp,Bp_1,Bp_2,Ap_2,Ap_1,Ap,JobName,K2,side_cable_a,side_cable_b,side_cable_c,side_cable_d,pylon_geo_6000_1,pylon_geo_6000_end,pylon_geo_8000_1,pylon_geo_8000_end,Girder_geo_main_test,Girder_geo_2000_test,Girder_geo_4000_test,cross_beam_geo_2000,cross_beam_geo_4000,cable_geo_6000_test,cable_geo_8000_test,side_cables_geo_test,pylon_geo,crossbeams_pylon,cable_el_8000,cable_el_6000,Girder_el_main_test,cross_beam_el_2000,cross_beam_el_4000,Girder_el_2000_test,Girder_el_4000_test,hanger_2000_el,hanger_4000_el,pylon_el,crossbeam_pylonbed_1_el,crossbeam_pylonbed_end_el,crossbeam_pylontop_1_el,crossbeam_pylontop_end_el,crossbeam_pylonmid_1,crossbeam_pylonmid_end);
%%
clc
copy_to_command_window= ['abaqus job=' JobName ' input=' JobName ' interactive']

% system(['abaqus job=' JobName ' input=' JobName '\' JobName  ' interactive'])
% pause(2)
% winopen([JobName '\' JobName '.odb']);
